Maak eerst een map "MySQL" met daarin een map "Essentieel".

Op DigitAP staan drie "debug scripts" als bijlage bij deze file.
Deze bevatten allemaal enkele fouten.
Corrigeer de fouten in elke file en sla de files op onder:

- MySQL/Essentieel/debug-script-1.sql
- MySQL/Essentieel/debug-script-2.sql
- MySQL/Essentieel/debug-script-3.sql

Zorg dat de files correct uitvoeren en dat je in de tabellen het gewenste resultaat kan zien.
